@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000, 2001 Christian Kreibich <kreibich@aciri.org>.
+Copyright (C) 2000, 2001, 2002 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -26,10 +26,13 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #define __nd_globals_h
 
 #include <gtk/gtk.h>
-#include <nd_tracefile.h>
 
+/* Let's make some useful goodies available everywhere: */
+
+/* The toplevel main window of the application */
 extern GtkWidget   *toplevel;
-extern ND_Trace     trace;
 
+/* A global error buffer for use with pcap */
+extern char         pcap_errbuf[];
 
 #endif
