@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000, 2001 Christian Kreibich <kreibich@aciri.org>.
+Copyright (C) 2000, 2001, 2002 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -25,15 +25,35 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #ifndef __nd_main_h
 #define __nd_main_h
 
-#include <stdlib.h>
-#include <gtk/gtk.h>
+#include <glib.h>
 
-/* Exits if tracefile hasn't changed,
-   otherwise brings up confirmation dialog.
-*/
+typedef struct nd_cmd_options
+{
+  /* When TRUE, enable debugging output: */
+  gboolean     debug;
+
+  /* When TRUE, list all registered protocols, then exit: */
+  gboolean     show_protos;
+
+} ND_CmdOptions;
+
+extern ND_CmdOptions cmd_options;
+
+/**
+ * nd_main_safe_exit - exit routine with trace state checking.
+ *
+ * The function causes Netdude to exit. If there are any modified
+ * traces still open, the exit dialog is shown for confirmation.
+ */
 void     nd_main_safe_exit(void);
 
-/* Exits without changing tracefile status. */
+/**
+ * nd_main_unsafe_exit - fast exit.
+ *
+ * The function causes Netdude to exit immediately, without
+ * checking for unsaved files etc. Called by nd_main_safe_exit()
+ * when there are no unsaved traces.
+ */
 void     nd_main_unsafe_exit(void);
 
 #endif
