@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000, 2001 Christian Kreibich <kreibich@aciri.org>.
+Copyright (C) 2000, 2001, 2002 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -29,9 +29,39 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #define NUM_RECENT 5
 
+/**
+ * nd_recent_init - initializes recently-used-files management.
+ *
+ * The function initializes everything needed to keep track of the
+ * trace files recently used, such as the menu items in the File
+ * menu.
+ */
 void nd_recent_init(void);
+
+/**
+ * nd_recent_reload_entries - updates recently-used items.
+ *
+ * The function updates the menu items in the File menu to
+ * the current preference settings.
+ */
 void nd_recent_reload_entries(void);
-void nd_recent_add_file(char *filename);
+
+/**
+ * nd_recent_add_file - adds a file to the recently-used list.
+ * @filename: filename to add.
+ *
+ * The function adds @filename to the list of recently-used
+ * files.
+ */
+void nd_recent_add_file(const char *filename);
+
+/**
+ * nd_recent_load - loads a recently-used trace.
+ * @index: index of recently used file.
+ *
+ * The function takes the @index-th recent file and loads
+ * it.
+ */
 void nd_recent_load(int index);
 
 #endif
