@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000, 2001 Christian Kreibich <kreibich@aciri.org>.
+Copyright (C) 2000, 2001, 2002 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -25,13 +25,6 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #ifndef __nd_timestamp_h
 #define __nd_timestamp_h
 
-#define LAST_UPDATE  "$Date: 2001/09/23 17:07:32 $"
-
-#ifdef RELEASE
-#  define WELCOMESTRING   "Welcome to NetDude, Version " VERSION "."
-#else
-#  define WELCOMESTRING   "Welcome to NetDude, DEVELOPMENT Version " VERSION ",  last updated on " LAST_UPDATE "."
-#endif
+#define LAST_UPDATE "Tue Nov 12 19:53:54 GMT 2002"
 
 #endif
-      
\ No newline at end of file
